==> zio-aws-macie2_2.12-6.20.97.2-sources.jar: zio/aws/macie2/model/S3WordsList.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.{
  __stringMin1Max1024PatternSS,
  __stringMin3Max255PatternAZaZ093255
}
import scala.jdk.CollectionConverters._
final case class S3WordsList(
    bucketName: __stringMin3Max255PatternAZaZ093255,
    objectKey: __stringMin1Max1024PatternSS
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.S3WordsList = {
    import S3WordsList.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.S3WordsList
      .builder()
      .bucketName(bucketName: java.lang.String)
      .objectKey(objectKey: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.S3WordsList.ReadOnly =
    zio.aws.macie2.model.S3WordsList.wrap(buildAwsValue())
}
object S3WordsList {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.S3WordsList
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.S3WordsList =
      zio.aws.macie2.model.S3WordsList(bucketName, objectKey)
    def bucketName: __stringMin3Max255PatternAZaZ093255
    def objectKey: __stringMin1Max1024PatternSS
    def getBucketName: ZIO[Any, Nothing, __stringMin3Max255PatternAZaZ093255] =
      ZIO.succeed(bucketName)
    def getObjectKey: ZIO[Any, Nothing, __stringMin1Max1024PatternSS] =
      ZIO.succeed(objectKey)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.S3WordsList
  ) extends zio.aws.macie2.model.S3WordsList.ReadOnly {
    override val bucketName: __stringMin3Max255PatternAZaZ093255 =
      impl.bucketName(): __stringMin3Max255PatternAZaZ093255
    override val objectKey: __stringMin1Max1024PatternSS =
      impl.objectKey(): __stringMin1Max1024PatternSS
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.S3WordsList
  ): zio.aws.macie2.model.S3WordsList.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_3-5.19.8.3-sources.jar: zio/aws/macie2/model/S3WordsList.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.{
  __stringMin1Max1024PatternSS,
  __stringMin3Max255PatternAZaZ093255
}
import scala.jdk.CollectionConverters.*
final case class S3WordsList(
    bucketName: __stringMin3Max255PatternAZaZ093255,
    objectKey: __stringMin1Max1024PatternSS
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.S3WordsList = {
    import S3WordsList.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.S3WordsList
      .builder()
      .bucketName(bucketName: java.lang.String)
      .objectKey(objectKey: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.S3WordsList.ReadOnly =
    zio.aws.macie2.model.S3WordsList.wrap(buildAwsValue())
}
object S3WordsList {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.S3WordsList
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.S3WordsList =
      zio.aws.macie2.model.S3WordsList(bucketName, objectKey)
    def bucketName: __stringMin3Max255PatternAZaZ093255
    def objectKey: __stringMin1Max1024PatternSS
    def getBucketName: ZIO[Any, Nothing, __stringMin3Max255PatternAZaZ093255] =
      ZIO.succeed(bucketName)
    def getObjectKey: ZIO[Any, Nothing, __stringMin1Max1024PatternSS] =
      ZIO.succeed(objectKey)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.S3WordsList
  ) extends zio.aws.macie2.model.S3WordsList.ReadOnly {
    override val bucketName: __stringMin3Max255PatternAZaZ093255 =
      impl.bucketName(): __stringMin3Max255PatternAZaZ093255
    override val objectKey: __stringMin1Max1024PatternSS =
      impl.objectKey(): __stringMin1Max1024PatternSS
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.S3WordsList
  ): zio.aws.macie2.model.S3WordsList.ReadOnly = new Wrapper(impl)
}
